@@ -4,7 +4,7 @@ Atensorfn <- function(modelList, coefList) {
   #  Each member of AtensorList[[ivar]] is a list of length NFORCEI
   #  and each member of this is a list of length NFORCEI
 
-  #  Last modified 22 May 2018
+  #  Last modified 14 December 2018
 
   nvar <- length(modelList)
   AtensorList <- vector("list", nvar)
@@ -65,7 +65,7 @@ Atensorfn <- function(modelList, coefList) {
                   Utypev == "bspline" && Utypex == "bspline") {
                 #  of both coefficients have constant bases, use inprod.Data2LD
                 # print("Calling inprod.Data2LD")
-                XWXWmatij <- inprod.Data2LD(Ubasisv, Ubasisx, 0, 0)
+                XWXWmatij <- inprod(Ubasisv, Ubasisx, 0, 0)
                 XWXWmatij <- matrix(XWXWmatij, nUbasisv*nUbasisx, 1)
               } else {
                 # otherwise use inprod.TPbasis
