@@ -1,4 +1,4 @@
-#  set up the 194 by 3 matrix of refinery data from a .txt file
+#  set up the 194 by 3 matrix of refinery data
 
 N <- 194
 TimeData <- RefineryData[,1]
@@ -11,7 +11,7 @@ lines(c(67,67), c(0,4.0), type="l")
 plot(TimeData, ValvData, type="p")
 lines(c(67,67), c(0,0.5), type="l")
 
-#  Construct a step basis (order 1) for smoothing valve level
+#  Construct a step basis (order 1) and valve level
 
 Valvbreaks <- c(0,67,193)
 Valvnbasis <- 2
@@ -33,9 +33,9 @@ conbasis <- create.constant.basis(c(0,193))
 #  store these in a coefficient function list
 #  Use positive random initial values for testing purposes
 TrayCoefList <- vector("list",2)
-TrayCoefList[[1]] <- make.coef(fun=conbasis, parvec=exp(rnorm(1)), 
+TrayCoefList[[1]] <- make.Coef(fun=conbasis, parvec=exp(rnorm(1)), 
                                estimate=TRUE)
-TrayCoefList[[2]] <- make.coef(fun=conbasis, parvec=exp(rnorm(1)), 
+TrayCoefList[[2]] <- make.Coef(fun=conbasis, parvec=exp(rnorm(1)), 
                                estimate=TRUE)
 
 #  Run a check on the coefficient List array, 
@@ -49,7 +49,8 @@ TrayNtheta     <- TraycoefResult$ntheta
 
 #  Define single homogeneous term
 
-XTerm <- make.Xterm(variable=1, derivative=0, ncoef=1, factor=-1, name="reaction")
+XTerm <- make.Xterm(variable=1, derivative=0, ncoef=1, 
+                    factor=-1, name="reaction")
 XList <- vector("list", 1)
 XList[[1]] <- XTerm
 
@@ -61,22 +62,13 @@ FList[[1]] <- FTerm
 
 #  Define the single differential equation in the model
 
-TrayVariable <- make.variable(XList=XList, FList=FList, name="Tray level", order=1)
+TrayVariable <- make.Variable(XList=XList, FList=FList, 
+                              name="Tray level", order=1)
 
 #  Set up the model List array
 
-TrayModelList <- vector("list",1)
-TrayModelList[[1]] <- TrayVariable
-
-#  Run a check on TrayModelList
-
-TrayModelList <- modelCheck(TrayModelList, TrayCoefList)
-
-#  Define the List array containing the tray data
-
-TrayList <- list(argvals=RefineryData[,1], y=RefineryData[,2])
-TrayDataList  <- vector("list",1)
-TrayDataList[[1]] <- TrayList
+TrayVariableList <- vector("list",1)
+TrayVariableList[[1]] <- TrayVariable
 
 # construct the basis object for tray variable
 #  Order 5 spline basis with four knots at the 67
@@ -86,7 +78,8 @@ TrayDataList[[1]] <- TrayList
 Traynorder <- 5
 Traybreaks <- c(0, rep(67,3), seq(67, 193, len=15))
 Traynbasis <- 22
-TrayBasis  <- create.bspline.basis(c(0,193), Traynbasis, Traynorder, Traybreaks)
+TrayBasis  <- create.bspline.basis(c(0,193), Traynbasis, Traynorder, 
+                                   Traybreaks)
 
 #  plot the basis
 
@@ -98,11 +91,23 @@ plot(TrayBasis, xlab="Time", ylab="B-spline basis functions")
 TrayBasisList    <- vector("list",1)
 TrayBasisList[[1]] <- TrayBasis
 
+#  Run a check on TrayVariableList and make the modelList object
+
+TrayModelList <- make.Model(TrayBasisList, TrayVariableList, TrayCoefList)
+
+#  Define the List array containing the tray data
+
+TrayList <- list(argvals=RefineryData[,1], y=RefineryData[,2])
+TrayDataList  <- vector("list",1)
+TrayDataList[[1]] <- TrayList
+
 #  Evaluate the fit to the data given the initial parameter estimates (0 and 0)
 #  This also initializes the four-way tensors so that they are not re-computed
 #  for subsquent analyses.
 
-Data2LDList <- Data2LD(TrayDataList, TrayBasisList, TrayModelList, TrayCoefList, rhoVec)
+rhoVec <- 0.5
+Data2LDList <- Data2LD(TrayDataList, TrayBasisList, TrayModelList, 
+                       TrayCoefList, rhoVec)
 MSE  <- Data2LDList$MSE    # Mean squared error for fit to data
 DMSE <- Data2LDList$DpMSE  #  gradient with respect to parameter values
 
@@ -113,23 +118,26 @@ iterlim  <- 50    #  maximum number of iterations
 convrg   <- c(1e-8, 1e-4)  #  convergence criterion
 
 gammavec <- 0:7
-rhoVec   <- exp(gammavec)/(1+exp(gammavec))
-nrho    <- length(rhoVec)
-dfesave <- matrix(0,nrho,1)
-gcvsave <- matrix(0,nrho,1)
-MSEsave <- matrix(0,nrho,1)
-thesave <- matrix(0,nrho,TrayNtheta)
+nrho <- length(gammavec)
+rhoMat   <- as.matrix(exp(gammavec)/(1+exp(gammavec)),nrho,1)
+dfesave  <- matrix(0,nrho,1)
+gcvsave  <- matrix(0,nrho,1)
+MSEsave  <- matrix(0,nrho,1)
+thesave  <- matrix(0,nrho,TrayNtheta)
 
 TrayCoefList.opt <- TrayCoefList
 
 for (irho in 1:nrho) {
-  rhoi <- rhoVec[irho]
+  rhoi <- rhoMat[irho]
   print(paste("rho <- ",round(rhoi,5)))
-  Data2LDResult <- Data2LD.opt(TrayDataList, TrayBasisList, TrayModelList, TrayCoefList.opt, 
-                               rhoi, convrg, iterlim, dbglev)
+  Data2LDResult <- Data2LD.opt(TrayDataList, TrayBasisList, 
+                               TrayModelList,  TrayCoefList.opt, 
+                               rhoi, convrg, 
+                               iterlim, dbglev)
   theta.opti <- Data2LDResult$thetastore
   TrayCoefList.opti <- modelVec2List(theta.opti, TrayCoefList)
-  Data2LDList <- Data2LD(TrayDataList, TrayBasisList, TrayModelList, TrayCoefList.opti, rhoi)
+  Data2LDList <- Data2LD(TrayDataList, TrayBasisList, TrayModelList, 
+                         TrayCoefList.opti, rhoi)
   MSE       <- Data2LDList$MSE 
   df        <- Data2LDList$df
   gcv       <- Data2LDList$gcv 
@@ -143,19 +151,17 @@ for (irho in 1:nrho) {
 
 # print degrees of freedom and gcv values
 
-print("    rho      df         gcv")
+print("    rho      df         gcv,       MSE")
 for (irho in 1:nrho) {
-  print(round(c(rhoVec[irho], dfesave[irho], gcvsave[irho]),5))
+  print(round(c(rhoMat[irho,1], dfesave[irho], gcvsave[irho], MSEsave[irho]),5))
 }
 
-
 ## Evaluate the fit for (parameter values at highest rho value
 
 irho <- 8  #  evaluate solution for (highest rho value
-theta <- thesave[irho,]
-coefList <- BAwTimeData2list(theta, coefList)
-rho <- rhoVec[irho]
-Data2LDList <- Data2LD(TrayDataList, TrayBasisList, TrayModelList, coefList, rho)
+TrayCoefList <- modelVec2List(thesave[irho,], TrayCoefList)
+Data2LDList <- Data2LD(TrayDataList, TrayBasisList, TrayModelList, 
+                       TrayCoefList, rhoMat[irho,])
 MSE       <- Data2LDList$MSE 
 df        <- Data2LDList$df
 gcv       <- Data2LDList$gcv 
@@ -165,10 +171,10 @@ print(paste("MSE = ", round(MSE,5)))
 print(paste("df  = ", round(df,1)))
 print(paste("gcv = ", round(gcv,5)))
 
-Trayfd        <- Data2LDList$XfdParList[[1]]$fd
-tfine         <- seq(0,193,len=101)
-Trayfine      <- eval.fd(tfine, Trayfd)
-Ufine         <- eval.fd(tfine, Valvfd)
+Trayfd   <- Data2LDList$XfdParList[[1]]$fd
+tfine    <- seq(0,193,len=101)
+Trayfine <- eval.fd(tfine, Trayfd)
+Ufine    <- eval.fd(tfine, Valvfd)
 
 # plot fit of solution to data
 
@@ -179,6 +185,7 @@ points(TimeData, TrayData)
 
 # compute the derivative Dx(t) and the right side of the equation
 
+theta <- thesave[irho,]
 DTrayData <- eval.fd(TimeData, Trayfd, 1)
 DTrayfit  <- -theta[1]*Trayfine + theta[2]*Ufine
 
@@ -200,5 +207,7 @@ print(round(c(theta[2], thetaDN[2], thetaUP[2], stderr[2]),4))
 ##  plot the evolution of the parameters over the values of rho
 
 par(mfrow=c(2,1))
-plot(rhoVec, thesave[,1], type <- "b", lwd=2, xlab="rho", ylab="rate parameter")
-plot(rhoVec, thesave[,2], type <- "b", lwd=2, xlab="rho", ylab="forcing parameter")
+plot(rhoMat, thesave[,1], type <- "b", lwd=2, 
+     xlab="rho", ylab="rate parameter")
+plot(rhoMat, thesave[,2], type <- "b", lwd=2, 
+     xlab="rho", ylab="forcing parameter")
